function [ Ceq ] = chain_eqconstraints( x, param )
% implements the equality constraints for the rigid link chain
% i.e. each mass has to have a distance of L/(N+1) to its neighbour(s)
% assumes x is ordered as x = [y1, z1, ..., yN, zN]

N = size(x,1)/2;    % Note that N is here the number of FREE masses
y = x(1:2:2*N);
z = x(2:2:2*N);

% distance between to mass points
LoN = param.L / (N+1);

% position of outermost masses
xi = param.xi;
xf = param.xf;

% start out with empty set of constraints
Ceq = [];
% add distance constraints between free masses
Ceq = [Ceq; diff(y).^2 + diff(z).^2 - LoN^2];
% add distance constraints including the fixed points
Ceq = [Ceq; (xi(1) - y(1))^2   + (xi(2) - z(1))^2 - LoN^2];
Ceq = [Ceq; (xf(1) - y(end))^2 + (xf(2) - z(end))^2 - LoN^2];

% Consistent constraint
% Ceq = [Ceq; z(round(N/2))-0.6];
% Ceq = [Ceq; y(round(N/2))];

% LICQ violation
% Ceq = [Ceq; y(1)+2];
% Ceq = [Ceq; z(1)-(xi(2)-LoN)];

% Infeasibility
% Ceq = [Ceq; y(1)+2];
% Ceq = [Ceq; z(1)-(xi(2)-LoN)-0.01];
